| strawberry | R Documentation |
Strawberry growth rates for different pesticides.
data(strawberry)
A data frame with 28 rows and four columns.
the experimental block
the pesticide applied to the plant. Pesticide O is a control.
a measure of the growth rate of strawberry plants with pesticide applied.
rank of the response
Pesticides are applied to strawberry plants to inhibit the growth of weeds. The question is, do they also inhibit the growth of the strawberries? The design is a supplemented balanced design.
Pearce (1960)
Pearce, S.C. (1960). Supplemented balanced. Biometrika, 47, 263-271.
attach(strawberry) lm_strawberry = lm(rank~pesticide+block) anova(lm_strawberry)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.